#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import mistune

from reader.markdown import MyRenderer

def to_unicode(value):
    if isinstance(value, unicode):
        return value
    if isinstance(value, basestring):
        return value.decode('utf-8')
    if isinstance(value, int):
        return str(value)
    if isinstance(value, bytes):
        return value.decode('utf-8')
    return value

def mkdir(path):
    if not os.path.exists(path):
        os.makedirs(path)

def md_to_html(text):
    text = to_unicode(text)
    renderer = MyRenderer()
    md = mistune.Markdown(renderer=renderer)
    return md.render(text)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

class DictSpace(dict):
    def __getattr__(self, key):
        if key in self:
            return self[key]
        else:
            raise AttributeError

    def __setattr__(self, key, value):
        self[key] = value

    def __delattr__(self, key):
        try:
            del self[key]
        except:
            raise AttributeError

hub = DictSpace()
hub.root = DictSpace()
hub.site = DictSpace()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import shutil

major = sys.version_info[0]
if major < 3:
    reload(sys)
    sys.setdefaultencoding('utf-8')

from .utils import *
from .options import *

from reader.reader import *
from generator.render import *

import aam

doc = """Aam v%s
Usage:
    aam init
    aam build
    aam -h | --help
    aam --version

Options:
    -h --help               Show this screen and exit.
""" % aam.__version__

from parguments import Parguments

parguments = Parguments(doc, version=aam.__version__)

def pre_init():
    hub.root.path = os.path.dirname(__file__)
    hub.root.template_path = os.path.join(os.path.dirname(__file__),'templates')
    hub.root.static_path = os.path.join(os.path.dirname(__file__), 'static')
    hub.site.path = os.getcwd()
    hub.site.page_path = os.path.join(hub.site.path, 'pages')
    hub.site.deploy_path = os.path.join(hub.site.path, 'deploy')
    hub.site.static_path = os.path.join(hub.site.deploy_path, 'static')

@parguments.command
def init():
    """
    Usage:
        aam init

    Options:
        -h --help               Show this screen and exit.
    """
    pre_init()
    mkdir("pages")
    mkdir("deploy")
    shutil.copyfile(os.path.join(hub.root.path, 'config.ini'), 'config.ini')
    print("Please edit config.py to config your site")

@parguments.command
def build():
    """
    Usage:
        aam build

    Options:
        -h --help               Show this screen and exit.
    """
    pre_init()
    read_config()
    read_page()
    render()
    print("Build Finished.")

def main():
    parguments.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

import aam

version = aam.__version__

long_description = open('README.rst').read()

setup(
    name='aam',
    version=version,
    author='JmPotato',
    author_email='ghzpotato@gmail.com',
    url='https://github.com/JmPotato/Aam',
    packages=find_packages(),
    description='a lightweight about me site generator',
    long_description=long_description,
    keywords="Aam, about me, site, static, static page, static site, generator",
    entry_points={
        'console_scripts': ['aam=aam.cli:main'],
    },
    install_requires=open("requirements.txt").readlines(),
    include_package_data=True,
    license='MIT License',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
    ],
)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import shutil

from aam.options import *
from aam.utils import mkdir

from jinja2 import Environment, FileSystemLoader, TemplateNotFound

def render():
    env = Environment(
        loader=FileSystemLoader(hub.root.template_path, encoding='utf-8'),
        autoescape=False
    )
    env.globals.update(
        title = hub.site.name,
        site_url = hub.site.url,
        site_name = hub.site.name,
        site_owner = hub.site.owner,
        pages = hub.site.pages,
        repo_switch = hub.site.repo_switch,
        book_switch = hub.site.book_switch,
    )

    if not os.path.exists(hub.site.deploy_path):
        print("Can't find deploy folder. Please creat a new one or use \'aam init\'.")
        exit(1)
    shutil.rmtree(hub.site.deploy_path)
    os.chdir(hub.site.path)
    mkdir("deploy")

    for page in hub.site.pages:
        if page["type"] == "page":
            output_path = os.path.join(hub.site.path, "deploy/%s" % page['link'])
            html = env.get_template("page.html").render(
                title = hub.site.name + " | " + page['title'],
                page = page,
                )
            with open(output_path, "w") as f:
                f.write(html)
        elif page["type"] == "home":
            home = env.get_template("home.html").render(home = page)
            output_path = os.path.join(hub.site.deploy_path, "Home.html")
            with open(output_path, "w") as f:
                f.write(home)

    if hub.site.repo_switch:
        html = env.get_template("repo.html").render(
                title = hub.site.name + " | " + "Github Repo",
                repos = hub.site.github_repo,
                )
        with open(os.path.join(hub.site.deploy_path, "github_repo.html"), "w") as f:
                f.write(html)

    if hub.site.book_switch:
        html = env.get_template("douban.html").render(
                title = hub.site.name + " | " + "Douban Book",
                douban_name = hub.site.douban_name,
                )
        with open(os.path.join(hub.site.deploy_path, "douban_book.html"), "w") as f:
                f.write(html)

    shutil.copytree(hub.root.static_path, hub.site.static_path)
